from setuptools import setup, find_packages

setup(
    name='amazon_india_affiliate',
    version='0.2',
    description='A Python library designed to simplify the process of converting Amazon India URLs into affiliate links. This library is not affiliated with Amazon or its official services.',
    author='Aby Varghese',
    packages=find_packages(),
)